<?php
/*##################################################
 *		               BlogsDisplayBlogsController.class.php
 *                            -------------------
 *   begin                : February 15, 2013
 *   copyright            : (C) 2013 Kevin MASSY
 *   email                : kevin.massy@phpboost.com
 *
 *
 ###################################################
 *	Modules News : Dupliqu et modifi
 *--------------------------------------------------
 * Date: 01.06.2016
 * Par: Swan | EDN
 * Site: http://easy-design.net
 * Contact : contact@easy-design.net
 *
 ###################################################
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 ###################################################*/

/**
 * @author Kevin MASSY <kevin.massy@phpboost.com>
 */
class BlogsDisplayBlogsController extends ModuleController
{	
	private $lang;
	private $tpl;
	
	private $blogs;
	
	public function execute(HTTPRequestCustom $request)
	{
		$this->check_authorizations();
		
		$this->init();
		
		$this->build_view();
		
		return $this->generate_response();
	}
	
	private function init()
	{
		$this->lang = LangLoader::get('common', 'blogs');
		$this->tpl = new FileTemplate('blogs/BlogsDisplayBlogsController.tpl');
		$this->tpl->add_lang($this->lang);
	}
	
	private function get_blogs()
	{
		if ($this->blogs === null)
		{
			$id = AppContext::get_request()->get_getint('id', 0);
			if (!empty($id))
			{
				try {
					$this->blogs = BlogsService::get_blogs('WHERE id=:id', array('id' => $id));
				} catch (RowNotFoundException $e) {
					$error_controller = PHPBoostErrors::unexisting_page();
					DispatchManager::redirect($error_controller);
				}
			}
			else
				$this->blogs = new Blogs();
		}
		return $this->blogs;
	}
	
	private function build_view()
	{
		$blogs = $this->get_blogs();
		$blogs_config = BlogsConfig::load();
		$category = $blogs->get_category();
		
		$this->tpl->put_all(array_merge($blogs->get_array_tpl_vars(), array(
			'C_COMMENTS_ENABLED' => $blogs_config->get_comments_enabled(),
			'NOT_VISIBLE_MESSAGE' => MessageHelper::display(LangLoader::get_message('element.not_visible', 'status-messages-common'), MessageHelper::WARNING)
		)));
		
		if (BlogsConfig::load()->get_comments_enabled())
		{
			$comments_topic = new BlogsCommentsTopic($blogs);
			$comments_topic->set_id_in_module($blogs->get_id());
			$comments_topic->set_url(BlogsUrlBuilder::display_blogs($category->get_id(), $category->get_rewrited_name(), $blogs->get_id(), $blogs->get_rewrited_name()));
			
			$this->tpl->put_all(array(
				'COMMENTS' => $comments_topic->display()
			));
		}
		
		$this->build_sources_view($blogs);
		$this->build_keywords_view($blogs);
		$this->build_suggested_blogs($blogs);
		$this->build_navigation_links($blogs);
	}
	
	private function build_sources_view(Blogs $blogs)
	{
		$sources = $blogs->get_sources();
		$nbr_sources = count($sources);
		$this->tpl->put('C_SOURCES', $nbr_sources > 0);
		
		$i = 1;
		foreach ($sources as $name => $url)
		{	
			$this->tpl->assign_block_vars('sources', array(
				'C_SEPARATOR' => $i < $nbr_sources,
				'NAME' => $name,
				'URL' => $url,
			));
			$i++;
		}
	}
	
	private function build_keywords_view(Blogs $blogs)
	{
		$keywords = $blogs->get_keywords();
		$nbr_keywords = count($keywords);
		$this->tpl->put('C_KEYWORDS', $nbr_keywords > 0);

		$i = 1;
		foreach ($keywords as $keyword)
		{	
			$this->tpl->assign_block_vars('keywords', array(
				'C_SEPARATOR' => $i < $nbr_keywords,
				'NAME' => $keyword->get_name(),
				'URL' => BlogsUrlBuilder::display_tag($keyword->get_rewrited_name())->rel(),
			));
			$i++;
		}
	}
	
	
	private function build_suggested_blogs(Blogs $blogs)
	{
		$now = new Date();
		
		$result = PersistenceContext::get_querier()->select('
		SELECT id, name, id_category, rewrited_name, 
		(2 * FT_SEARCH_RELEVANCE(name, :search_content) + FT_SEARCH_RELEVANCE(contents, :search_content) / 3) AS relevance
		FROM ' . BlogsSetup::$blogs_table . '
		WHERE (FT_SEARCH(name, :search_content) OR FT_SEARCH(contents, :search_content)) AND id <> :excluded_id
		AND (approbation_type = 1 OR (approbation_type = 2 AND start_date < :timestamp_now AND (end_date > :timestamp_now OR end_date = 0)))
		ORDER BY relevance DESC LIMIT 0, 10', array(
			'excluded_id' => $blogs->get_id(),
			'search_content' => $blogs->get_name() .','. $blogs->get_contents(),
			'timestamp_now' => $now->get_timestamp()
		));
		
		$this->tpl->put('C_SUGGESTED_BLOGS', ($result->get_rows_count() > 0 && BlogsConfig::load()->get_blogs_suggestions_enabled()));
		
		while ($row = $result->fetch())
		{
			$this->tpl->assign_block_vars('suggested', array(
				'NAME' => $row['name'],
				'URL' => BlogsUrlBuilder::display_blogs($row['id_category'], BlogsService::get_categories_manager()->get_categories_cache()->get_category($row['id_category'])->get_rewrited_name(), $row['id'], $row['rewrited_name'])->rel()
			));
		}
		$result->dispose();
	}
	
	private function build_navigation_links(Blogs $blogs)
	{
		$now = new Date();
		$timestamp_blogs = $blogs->get_creation_date()->get_timestamp();

		$result = PersistenceContext::get_querier()->select('
		(SELECT id, name, id_category, rewrited_name, \'PREVIOUS\' as type
		FROM '. BlogsSetup::$blogs_table .'
		WHERE (approbation_type = 1 OR (approbation_type = 2 AND start_date < :timestamp_now AND (end_date > :timestamp_now OR end_date = 0))) AND creation_date < :timestamp_blogs AND id_category IN :authorized_categories ORDER BY creation_date DESC LIMIT 1 OFFSET 0)
		UNION
		(SELECT id, name, id_category, rewrited_name, \'NEXT\' as type
		FROM '. BlogsSetup::$blogs_table .'
		WHERE (approbation_type = 1 OR (approbation_type = 2 AND start_date < :timestamp_now AND (end_date > :timestamp_now OR end_date = 0))) AND creation_date > :timestamp_blogs AND id_category IN :authorized_categories ORDER BY creation_date ASC LIMIT 1 OFFSET 0)
		', array(
			'timestamp_now' => $now->get_timestamp(),
			'timestamp_blogs' => $timestamp_blogs,
			'authorized_categories' => array($blogs->get_id_cat())
		));
		
		while ($row = $result->fetch())
		{
			$this->tpl->put_all(array(
				'C_BLOGS_NAVIGATION_LINKS' => true,
				'C_'. $row['type'] .'_BLOGS' => true,
				$row['type'] . '_BLOGS' => $row['name'],
				'U_'. $row['type'] .'_BLOGS' => BlogsUrlBuilder::display_blogs($row['id_category'], BlogsService::get_categories_manager()->get_categories_cache()->get_category($row['id_category'])->get_rewrited_name(), $row['id'], $row['rewrited_name'])->rel(),
			));
		}
		$result->dispose();
	}
	
	private function check_authorizations()
	{
		$blogs = $this->get_blogs();
		
		$not_authorized = !BlogsAuthorizationsService::check_authorizations($blogs->get_id_cat())->moderation() && (!BlogsAuthorizationsService::check_authorizations($blogs->get_id_cat())->write() && $blogs->get_author_user()->get_id() != AppContext::get_current_user()->get_id());
		
		switch ($blogs->get_approbation_type()) {
			case Blogs::APPROVAL_NOW:
				if (!BlogsAuthorizationsService::check_authorizations($blogs->get_id_cat())->read() && $not_authorized)
				{
					$error_controller = PHPBoostErrors::user_not_authorized();
					DispatchManager::redirect($error_controller);
				}
			break;
			case Blogs::NOT_APPROVAL:
				if ($not_authorized)
				{
					$error_controller = PHPBoostErrors::user_not_authorized();
					DispatchManager::redirect($error_controller);
				}
			break;
			case Blogs::APPROVAL_DATE:
				if (!$blogs->is_visible() && $not_authorized)
				{
					$error_controller = PHPBoostErrors::user_not_authorized();
					DispatchManager::redirect($error_controller);
				}
			break;
			default:
				$error_controller = PHPBoostErrors::unexisting_page();
				DispatchManager::redirect($error_controller);
			break;
		}
	}
	
	private function generate_response()
	{
		$category = $this->get_blogs()->get_category();
		$response = new SiteDisplayResponse($this->tpl);
		
		$graphical_environment = $response->get_graphical_environment();
		$graphical_environment->set_page_title($this->get_blogs()->get_name(), $this->lang['blogs']);
		$graphical_environment->get_seo_meta_data()->set_description($this->get_blogs()->get_short_contents());
		$graphical_environment->get_seo_meta_data()->set_canonical_url(BlogsUrlBuilder::display_blogs($category->get_id(), $category->get_rewrited_name(), $this->get_blogs()->get_id(), $this->get_blogs()->get_rewrited_name()));
		
		$breadcrumb = $graphical_environment->get_breadcrumb();
		$breadcrumb->add($this->lang['blogs'], BlogsUrlBuilder::home());
		
		$categories = array_reverse(BlogsService::get_categories_manager()->get_parents($this->get_blogs()->get_id_cat(), true));
		foreach ($categories as $id => $category)
		{
			if ($category->get_id() != Category::ROOT_CATEGORY)
				$breadcrumb->add($category->get_name(), BlogsUrlBuilder::display_category($category->get_id(), $category->get_rewrited_name()));
		}
		$breadcrumb->add($this->get_blogs()->get_name(), BlogsUrlBuilder::display_blogs($category->get_id(), $category->get_rewrited_name(), $this->get_blogs()->get_id(), $this->get_blogs()->get_rewrited_name()));
		
		return $response;
	}
}
?>
